@@ -1,7 +1,7 @@
 /*
  * node_device_conf.h: config handling for node devices
  *
- * Copyright (C) 2009-2013 Red Hat, Inc.
+ * Copyright (C) 2009-2014 Red Hat, Inc.
  * Copyright (C) 2008 Virtual Iron Software, Inc.
  * Copyright (C) 2008 David F. Lively
  *
@@ -81,33 +81,6 @@ typedef enum {
     VIR_NODE_DEV_CAP_FLAG_PCIE                      = (1 << 2),
 } virNodeDevPCICapFlags;
 
-typedef enum {
-    VIR_PCIE_LINK_SPEED_NA = 0,
-    VIR_PCIE_LINK_SPEED_25,
-    VIR_PCIE_LINK_SPEED_5,
-    VIR_PCIE_LINK_SPEED_8,
-    VIR_PCIE_LINK_SPEED_LAST
-} virPCIELinkSpeed;
-
-VIR_ENUM_DECL(virPCIELinkSpeed)
-
-typedef struct _virPCIELink virPCIELink;
-typedef virPCIELink *virPCIELinkPtr;
-struct _virPCIELink {
-    int port;
-    virPCIELinkSpeed speed;
-    unsigned int width;
-};
-
-typedef struct _virPCIEDeviceInfo virPCIEDeviceInfo;
-typedef virPCIEDeviceInfo *virPCIEDeviceInfoPtr;
-struct _virPCIEDeviceInfo {
-    /* Not all PCI Express devices has link. For example this 'Root Complex
-     * Integrated Endpoint' and 'Root Complex Event Collector' don't have it. */
-    virPCIELink *link_cap;   /* PCIe device link capabilities */
-    virPCIELink *link_sta;   /* Actually negotiated capabilities */
-};
-
 typedef struct _virNodeDevCapsDef virNodeDevCapsDef;
 typedef virNodeDevCapsDef *virNodeDevCapsDefPtr;
 struct _virNodeDevCapsDef {
@@ -171,6 +144,7 @@ struct _virNodeDevCapsDef {
         } net;
         struct {
             unsigned int host;
+            int unique_id;
             char *wwnn;
             char *wwpn;
             char *fabric_wwn;
